@@ -301,13 +301,13 @@ get_xdir (void)
 static void
 check_prefs_dir (void)
 {
-	char *xdir = get_xdir ();
-	if (access (xdir, F_OK) != 0)
+	char *dir = get_xdir ();
+	if (access (dir, F_OK) != 0)
 	{
 #ifdef WIN32
-		if (mkdir (xdir) != 0)
+		if (mkdir (dir) != 0)
 #else
-		if (mkdir (xdir, S_IRUSR | S_IWUSR | S_IXUSR) != 0)
+		if (mkdir (dir, S_IRUSR | S_IWUSR | S_IXUSR) != 0)
 #endif
 			fe_message (_("Cannot create ~/.xchat2"), FALSE);
 	}
@@ -539,7 +539,7 @@ load_config (void)
 	/*prefs.windows_as_tabs = 1;*/
 	prefs.privmsgtab = 1;
 	prefs.style_inputbox = 1;
-	prefs.slist_select = 9;
+	/*prefs.slist_select = 99;*/
 	prefs.nu_color = 4;
 	prefs.dccpermissions = 0600;
 	prefs.max_lines = 300;
