@@ -44,7 +44,7 @@ identd (void *unused)
 
 	snprintf (outbuf, sizeof (outbuf), "%%\tServicing ident request from %s\n",
 				 inet_ntoa (addr.sin_addr));
-	PrintText (menu_sess, outbuf);
+	PrintText (current_sess, outbuf);
 
 	recv (read_sok, buf, sizeof (buf) - 1, 0);
 	buf[sizeof (buf) - 1] = 0;	  /* ensure null termination */
