@@ -695,7 +695,7 @@ cmd_dcc (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 		}
 		if (!strcasecmp (type, "LIST"))
 		{
-			dcc_show_list (sess, tbuf);
+			dcc_show_list (sess);
 			return TRUE;
 		}
 		if (!strcasecmp (type, "GET"))
@@ -755,7 +755,7 @@ cmd_dcc (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 			return TRUE;
 		}
 	} else
-		dcc_show_list (sess, tbuf);
+		dcc_show_list (sess);
 	return TRUE;
 }
 
@@ -1691,7 +1691,7 @@ cmd_ignore (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 		if (!strcasecmp (word[i], "UNIGNORE"))
 			type |= IG_UNIG;
 		else if (!strcasecmp (word[i], "ALL"))
-			type |= IG_PRIV | IG_NOTI | IG_CHAN | IG_CTCP | IG_INVI;
+			type |= IG_PRIV | IG_NOTI | IG_CHAN | IG_CTCP | IG_INVI | IG_DCC;
 		else if (!strcasecmp (word[i], "PRIV"))
 			type |= IG_PRIV;
 		else if (!strcasecmp (word[i], "NOTI"))
@@ -1706,6 +1706,8 @@ cmd_ignore (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 			quiet = 1;
 		else if (!strcasecmp (word[i], "NOSAVE"))
 			type |= IG_NOSAVE;
+		else if (!strcasecmp (word[i], "DCC"))
+			type |= IG_DCC;
 		else
 		{
 			sprintf (tbuf, _("Unknown arg '%s' ignored."), word[i]);
@@ -1811,10 +1813,8 @@ lastlog (session *sess, char *search)
 
 	lastlog_sess = find_dialog (sess->server, "(lastlog)");
 	if (!lastlog_sess)
-	{
 		lastlog_sess = new_ircwindow (sess->server, "(lastlog)", SESS_DIALOG);
-		lastlog_sess->lastlog_sess = sess;
-	}
+	lastlog_sess->lastlog_sess = sess;
 
 	fe_text_clear (lastlog_sess);
 
@@ -2636,7 +2636,7 @@ const struct commands xc_cmds[] = {
 	 N_("IGNORE <mask> <types..> <options..>\n"
 	 "    mask - host mask to ignore, eg: *!*@*.aol.com\n"
 	 "    types - types of data to ignore, one or all of:\n"
-	 "            PRIV, CHAN, NOTI, CTCP, INVI, ALL\n"
+	 "            PRIV, CHAN, NOTI, CTCP, DCC, INVI, ALL\n"
 	 "    options - NOSAVE, QUIET")},
 
 	{"INVITE", cmd_invite, 1, 0,
