@@ -1005,7 +1005,7 @@ xchat_list_fields (xchat_plugin *ph, const char *name)
 	};
 	static const char *channels_fields[] =
 	{
-		"schannel",	"pcontext", "snetwork", "sserver",	"stype",	NULL
+		"schannel",	"pcontext", "snetwork", "sserver",	"itype",	NULL
 	};
 	static const char *ignore_fields[] =
 	{
@@ -1171,7 +1171,7 @@ int
 xchat_emit_print (xchat_plugin *ph, char *event_name, ...)
 {
 	va_list args;
-	char *argv[4];
+	char *argv[4] = {NULL, NULL, NULL, NULL};
 	int i = 0;
 
 	memset (&argv, 0, sizeof (argv));
