@@ -168,7 +168,7 @@ static void
 irc_away_status (server *serv, char *channel)
 {
 	if (serv->have_whox)
-		tcp_sendf (serv, "WHO %s %%cnf\r\n", channel);
+		tcp_sendf (serv, "WHO %s %%ctnf,152\r\n", channel);
 	else
 		tcp_sendf (serv, "WHO %s\r\n", channel);
 }
@@ -211,7 +211,9 @@ irc_notice (server *serv, char *channel, char *text)
 static void
 irc_topic (server *serv, char *channel, char *topic)
 {
-	if (topic[0])
+	if (!topic)
+		tcp_sendf (serv, "TOPIC %s :\r\n", channel);
+	else if (topic[0])
 		tcp_sendf (serv, "TOPIC %s :%s\r\n", channel, topic);
 	else
 		tcp_sendf (serv, "TOPIC %s\r\n", channel);
@@ -362,7 +364,7 @@ process_numeric (session * sess, int n,
 
 	case 317:
 		{
-			long n = atol (word[6]);
+			long nn = atol (word[6]);
 			long idle = atol (word[5]);
 			char *tim;
 			char outbuf[64];
@@ -370,12 +372,12 @@ process_numeric (session * sess, int n,
 			snprintf (outbuf, sizeof (outbuf),
 						"%02ld:%02ld:%02ld", idle / 3600, (idle / 60) % 60,
 						idle % 60);
-			if (n == 0)
+			if (nn == 0)
 				EMIT_SIGNAL (XP_TE_WHOIS4, serv->server_session, word[4],
 								 outbuf, NULL, NULL, 0);
 			else
 			{
-				tim = ctime (&n);
+				tim = ctime (&nn);
 				tim[19] = 0; 	/* get rid of the \n */
 				EMIT_SIGNAL (XP_TE_WHOIS4T, serv->server_session, word[4],
 								 outbuf, tim, NULL, 0);
@@ -469,10 +471,12 @@ process_numeric (session * sess, int n,
 		inbound_topictime (serv, word[4], word[5], atol (word[6]));
 		break;
 
+#if 0
 	case 338:  /* Undernet Real user@host, Real IP */
 		EMIT_SIGNAL (XP_TE_WHOIS_REALHOST, sess, word[4], word[5], word[6], 
 			(word_eol[7][0]==':') ? word_eol[7]+1 : word_eol[7], 0);
 		break;
+#endif
 
 	case 341:						  /* INVITE ACK */
 		EMIT_SIGNAL (XP_TE_UINVITE, sess, word[4], word[5], serv->servername,
@@ -485,7 +489,7 @@ process_numeric (session * sess, int n,
 			unsigned int away = 0;
 			session *who_sess = find_channel (serv, word[4]);
 
-			if (strchr (word[9], 'G'))
+			if (*word[9] == 'G')
 				away = 1;
 
 			inbound_user_info (sess, word[4], word[5], word[6], word[7],
@@ -505,18 +509,25 @@ process_numeric (session * sess, int n,
 	case 354:	/* undernet WHOX: used as a reply for irc_away_status */
 		{
 			unsigned int away = 0;
-			session *who_sess = find_channel (serv, word[4]);
+			session *who_sess;
 
-			if (strchr (word[6], 'G'))
-				away = 1;
+			/* irc_away_status sends out a "152" */
+			if (!strcmp (word[4], "152"))
+			{
+				who_sess = find_channel (serv, word[5]);
 
-			/* :SanJose.CA.us.undernet.org 354 z1 #zed1 z1 H@ */
-			inbound_user_info (sess, word[4], 0, 0, 0, word[5], 0, away);
+				if (*word[7] == 'G')
+					away = 1;
 
-			/* try to show only user initiated whos */
-			if (!who_sess || !who_sess->doing_who)
-				EMIT_SIGNAL (XP_TE_SERVTEXT, serv->server_session, text, word[1],
-								 NULL, NULL, 0);
+				/* :SanJose.CA.us.undernet.org 354 z1 152 #zed1 z1 H@ */
+				inbound_user_info (sess, word[5], 0, 0, 0, word[6], 0, away);
+
+				/* try to show only user initiated whos */
+				if (!who_sess || !who_sess->doing_who)
+					EMIT_SIGNAL (XP_TE_SERVTEXT, serv->server_session, text,
+									 word[1], NULL, NULL, 0);
+			} else
+				goto def;
 		}
 		break;
 
@@ -729,8 +740,6 @@ process_named_msg (session *sess, char *type, char *word[], char *word_eol[])
 				text++;
 				if (strncasecmp (text, "ACTION", 6) != 0)
 					flood_check (nick, ip, serv, sess, 0);
-				if (ignore_check (word[1], IG_CTCP))
-					return;
 				if (strncasecmp (text, "DCC ", 4) == 0)
 					/* redo this with handle_quotes TRUE */
 					process_data_init (word[1], word_eol[1], word, word_eol, TRUE);
