@@ -63,7 +63,7 @@ static const struct defaultserver def[] =
 
 	{"Aitvaras",	0},
 #ifdef USE_IPV6
-	{0,			"irc6.ktu.lt"},
+	{0,			"irc6.ktu.lt/7666"},
 #endif
 	{0,			"irc.delfi.lt"},
 	{0,			"irc.ktu.lt"},
@@ -142,12 +142,6 @@ static const struct defaultserver def[] =
 	{0,			"nc.d-t-net.de"},
 	{0,			"wakka.d-t-net.de"},
 
-	{"DwarfStarNet",	0},/*undersized*/
-	{0,			"IRC.dwarfstar.net"},
-	{0,			"US.dwarfstar.net"},
-	{0,			"EU.dwarfstar.net"},
-	{0,			"AU.dwarfstar.net"},
-
 	{"EFnet",	0},
 	{0,			"irc.Prison.NET"},
 	{0,			"irc.Qeast.net"},
@@ -822,7 +816,7 @@ servlist_net_add (char *name, char *comment)
 static void
 servlist_load_defaults (void)
 {
-	int i = 0;
+	int i = 0, j = 0;
 	ircnet *net = NULL;
 
 	while (1)
@@ -832,6 +826,9 @@ servlist_load_defaults (void)
 			net = servlist_net_add (def[i].network, def[i].host);
 			if (def[i].channel)
 				net->autojoin = strdup (def[i].channel);
+			if (!strcmp (def[i].network, "ChatJunkies"))
+				prefs.slist_select = j;
+			j++;
 		} else
 		{
 			servlist_server_add (net, def[i].host);
@@ -846,7 +843,7 @@ static int
 servlist_load (void)
 {
 	FILE *fp;
-	char buf[256];
+	char buf[258];
 	int len;
 	ircnet *net = NULL;
 
@@ -855,15 +852,15 @@ servlist_load (void)
 	if (!fp)
 		return FALSE;
 
-	while (fgets (buf, sizeof (buf) - 1, fp))
+	while (fgets (buf, sizeof (buf) - 2, fp))
 	{
 		len = strlen (buf);
+		buf[len] = 0;
 		buf[len-1] = 0;	/* remove the trailing \n */
-		switch (buf[0])
+		if (net)
 		{
-			case 'N':
-				net = servlist_net_add (buf + 2, /* comment */ "");
-				break;
+			switch (buf[0])
+			{
 			case 'I':
 				net->nick = strdup (buf + 2);
 				break;
@@ -894,7 +891,10 @@ servlist_load (void)
 			case 'S':	/* new server/hostname for this network */
 				servlist_server_add (net, buf + 2);
 				break;
+			}
 		}
+		if (buf[0] == 'N')
+			net = servlist_net_add (buf + 2, /* comment */ "");
 	}
 	fclose (fp);
 
