@@ -13,6 +13,7 @@ typedef struct ircnet
 	char *autojoin;
 	char *command;
 	char *comment;
+	char *encoding;
 	GSList *servlist;
 	int selected;
 	guint32 flags;
@@ -30,16 +31,17 @@ extern GSList *network_list;
 
 void servlist_init (void);
 void servlist_save (void);
-int servlist_load (void);
 int servlist_cycle (server *serv);
 void servlist_connect (session *sess, ircnet *net);
+int servlist_connect_by_netname (session *sess, char *network);
 int servlist_auto_connect (session *sess);
+int servlist_have_auto (void);
+int servlist_check_encoding (char *charset);
 
 ircnet *servlist_net_add (char *name, char *comment);
 void servlist_net_remove (ircnet *net);
-ircnet *servlist_net_find (char *name);
+ircnet *servlist_net_find (char *name, int *pos);
 
 void servlist_server_remove (ircnet *net, ircserver *serv);
-void servlist_server_remove_all (ircnet *net);
-void servlist_server_add (ircnet *net, char *name);
+ircserver *servlist_server_add (ircnet *net, char *name);
 ircserver *servlist_server_find (ircnet *net, char *name, int *pos);
