@@ -190,6 +190,7 @@ text_word_check (char *word)
 {
 	session *sess = current_sess;
 	char *at, *dot;
+	int i, dots;
 	int len = strlen (word);
 
 	if(q3link(word))
@@ -243,6 +244,21 @@ text_word_check (char *word)
 				return WORD_EMAIL;
 		}
 	}
+ 
+	/* check if it's an IP number */
+	dots = 0;
+	for (i = 0; i < len; i++)
+	{
+		if (word[i] == '.')
+			dots++;
+		else if (!isdigit (word[i]))
+		{
+			dots = 0;
+			break;
+		}
+	}
+	if (dots == 3)
+		return WORD_HOST;
 
 	if (!strncasecmp (word + len - 5, ".html", 5))
 		return WORD_HOST;
@@ -408,9 +424,22 @@ log_open_file (char *servname, char *channame, char *netname)
 void
 log_open (session *sess)
 {
+	static gboolean log_error = FALSE;
+
 	log_close (sess);
 	sess->logfd = log_open_file (sess->server->servername, sess->channel,
 										  sess->server->networkname);
+
+	if (!log_error && sess->logfd == -1)
+	{
+		char message[512];
+		snprintf (message, sizeof (message),
+					_("* Can't open log file(s) for writing. Check the\n" \
+					  "  permissions on %s/xchatlogs"), get_xdir());
+		fe_message (message, TRUE);
+
+		log_error = TRUE;
+	}
 }
 
 int
@@ -615,6 +644,11 @@ char *pntevts[NUM_XP];
 
 #define pevt_generic_none_help NULL
 
+static char *pevt_genmsg_help[] = {
+	N_("Left message"),
+	N_("Right message"),
+};
+
 static char *pevt_join_help[] = {
 	N_("The nick of the joining person"),
 	N_("The channel being joined"),
@@ -1591,6 +1625,15 @@ text_emit (int index, session *sess, char *a, char *b, char *c, char *d)
 	char *word[PDIWORDS];
 	int i;
 
+	if (!a)
+		a = "\000";
+	if (!b)
+		b = "\000";
+	if (!c)
+		c = "\000";
+	if (!d)
+		d = "\000";
+
 	word[0] = te[index].name;
 	word[1] = a;
 	word[2] = b;
@@ -1616,16 +1659,6 @@ text_emit_by_name (char *name, session *sess, char *a, char *b, char *c, char *d
 	i = pevent_find (name, &i);
 	if (i >= 0)
 	{
-		/* incase new args are added and plugins don't provide them */
-		if (!a && te[i].num_args > 0)
-			a = "";
-		if (!b && te[i].num_args > 1)
-			b = "";
-		if (!c && te[i].num_args > 2)
-			c = "";
-		if (!d && te[i].num_args > 3)
-			d = "";
-
 		text_emit (i, sess, a, b, c, d);
 		return 1;
 	}
