@@ -197,6 +197,9 @@ N_("-%C10-%C11-%O$tDisconnected ($1).")},
 {"Found IP", pevt_foundip_help, 1, 0,
 N_("-%C10-%C11-%O$tFound your IP: [$1]")},
 
+{"Generic Message", pevt_genmsg_help, 2, 0,
+N_("$1$t$2")},
+
 {"Ignore Add", pevt_ignoreaddremove_help, 1, 0,
 N_("%O%C11$1%O added to ignore list.")},
 
@@ -207,7 +210,7 @@ N_("Ignore on %C11$1%O changed.")},
 N_("%C08,02                                                         %O")},
 
 {"Ignore Header", pevt_generic_none_help, 0, 0,
-N_("%C08,02 Hostmask                  PRIV NOTI CHAN CTCP INVI UNIG %O")},
+N_("%C08,02 Hostmask                  PRIV NOTI CHAN CTCP DCC  INVI UNIG %O")},
 
 {"Ignore Remove", pevt_ignoreaddremove_help, 1, 0,
 N_("%O%C11$1%O removed from ignore list.")},
@@ -354,7 +357,7 @@ N_("-%C10-%C11-%O$t%C12[%O$1%C12]%C $2")},
 N_("-%C10-%C11-%O$t%C12[%O$1%C12] %CEnd of WHOIS list.")},
 
 {"WhoIs Identified", pevt_whoisid_help, 2, 0,
-N_("-%C10-%C11-%O$t%C12[%O$1%C12] %C$2")},
+N_("-%C10-%C11-%O$t%C12[%O$1%C12] %O$2")},
 
 {"WhoIs Authenticated", pevt_whoisauth_help, 3, 0,
 N_("-%C10-%C11-%O$t%C12[%O$1%C12] %O$2 %C11$3%O")},
