@@ -14,13 +14,16 @@ struct User
 	unsigned int hop:1;
 	unsigned int voice:1;
 	unsigned int me:1;
+	unsigned int away:1;
 };
 
 #define USERACCESS_SIZE 12
 
 int userlist_add_hostname (struct session *sess, char *nick,
 											 char *hostname, char *realname,
-											 char *servername);
+											 char *servername, unsigned int away);
+
+void userlist_set_away (struct session *sess, char *nick, unsigned int away);
 struct User *find_name (struct session *sess, char *name);
 struct User *find_name_global (struct server *serv, char *name);
 void update_user_list (struct session *sess);
@@ -32,3 +35,4 @@ int change_nick (struct session *sess, char *oldname, char *newname);
 void ul_update_entry (session *sess, char *name, char mode, char sign);
 void update_all_of (char *name);
 GSList *userlist_flat_list (session *sess);
+void userlist_rehash (session *sess);
