@@ -68,7 +68,7 @@ menu_about (GtkWidget * wid, gpointer sess)
 #endif
 
 	gtk_widget_show (gnome_about_new ("X-Chat", VERSION,
-							"(C) 1998-2002 Peter Zelezny", author, buf, 0));
+							"(C) 1998-2003 Peter Zelezny", author, buf, 0));
 }
 
 #else
@@ -88,6 +88,7 @@ menu_about (GtkWidget * wid, gpointer sess)
 	GtkWidget *vbox, *label, *hbox;
 	char buf[512];
 	const char *locale = NULL;
+	extern GtkWindow *parent_window;      /* maingui.c */
 
 	if (about)
 	{
@@ -99,6 +100,8 @@ menu_about (GtkWidget * wid, gpointer sess)
 	gtk_window_set_position (GTK_WINDOW (about), GTK_WIN_POS_CENTER);
 	gtk_window_set_resizable (GTK_WINDOW (about), FALSE);
 	gtk_window_set_title (GTK_WINDOW (about), _("About X-Chat"));
+	if (parent_window)
+		gtk_window_set_transient_for (GTK_WINDOW (about), parent_window);
 	g_signal_connect (G_OBJECT (about), "destroy",
 							G_CALLBACK (about_close), 0);
 
@@ -113,11 +116,11 @@ menu_about (GtkWidget * wid, gpointer sess)
 	g_get_charset (&locale);
 	(snprintf) (buf, sizeof (buf),
 				"<span size=\"x-large\"><b>X-Chat "VERSION"</b></span>\n\n"
-				"An IRC Client for UNIX\n\n"
+				"A multiplatform IRC Client\n\n"
 				"%s\n"
 				"<b>Charset</b>: %s <b>Renderer</b>: %s\n"
 				"<b>Compiled</b>: "__DATE__"\n\n"
-				"\302\251 1998-2002 Peter \305\275elezn\303\275 &lt;zed@xchat.org>",
+				"\302\251 1998-2003 Peter \305\275elezn\303\275 &lt;zed@xchat.org>",
 					get_cpu_str(),
 					locale,
 #ifdef USE_XFT
