@@ -256,10 +256,14 @@ mg_configure_cb (GtkWidget *wid, GdkEventConfigure *event, session *sess)
 			if (prefs.mainwindow_save)
 			{
 				sess = current_sess;
-				prefs.mainwindow_left = event->x;
+				gtk_window_get_position (GTK_WINDOW (wid), &prefs.mainwindow_left,
+												 &prefs.mainwindow_top);
+				gtk_window_get_size (GTK_WINDOW (wid), &prefs.mainwindow_width,
+												 &prefs.mainwindow_height);
+				/*prefs.mainwindow_left = event->x;
 				prefs.mainwindow_top = event->y;
 				prefs.mainwindow_width = event->width;
-				prefs.mainwindow_height = event->height;
+				prefs.mainwindow_height = event->height;*/
 			}
 		}
 	}
@@ -268,10 +272,14 @@ mg_configure_cb (GtkWidget *wid, GdkEventConfigure *event, session *sess)
 	{
 		if (sess->type == SESS_DIALOG && prefs.mainwindow_save)
 		{
-			prefs.dialog_left = event->x;
+			gtk_window_get_position (GTK_WINDOW (wid), &prefs.dialog_left,
+											 &prefs.dialog_top);
+			gtk_window_get_size (GTK_WINDOW (wid), &prefs.dialog_width,
+										&prefs.dialog_height);
+			/*prefs.dialog_left = event->x;
 			prefs.dialog_top = event->y;
 			prefs.dialog_width = event->width;
-			prefs.dialog_height = event->height;
+			prefs.dialog_height = event->height;*/
 		}
 
 		if (((GtkXText *) sess->gui->xtext)->transparent)
@@ -1136,7 +1144,7 @@ mg_topic_cb (GtkWidget *entry, gpointer userdata)
 	{
 		text = GTK_ENTRY (entry)->text;
 		if (text[0] == 0)
-			text = " ";
+			text = NULL;
 		sess->server->p_topic (sess->server, sess->channel, text);
 	} else
 		gtk_entry_set_text (GTK_ENTRY (entry), "");
@@ -1950,16 +1958,13 @@ mg_create_entry (session *sess, GtkWidget *box)
 	gui->nick_box = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (hbox), gui->nick_box, 0, 0, 0);
 
-	gui->nick_label = but = gtk_button_new_with_label (prefs.nick1);
+	gui->nick_label = but = gtk_button_new_with_label (sess->server->nick);
 	gtk_button_set_relief (GTK_BUTTON (but), GTK_RELIEF_NONE);
 	GTK_WIDGET_UNSET_FLAGS (but, GTK_CAN_FOCUS);
 	gtk_box_pack_end (GTK_BOX (gui->nick_box), but, 0, 0, 0);
 	g_signal_connect (G_OBJECT (but), "clicked",
 							G_CALLBACK (mg_nickclick_cb), NULL);
 
-	if (gui->is_tab)
-		sess = NULL;	/* pass NULL to key_handle_key_press for tabs */
-
 	gui->input_box = entry = gtk_entry_new ();
 	gtk_widget_set_name (entry, "xchat-inputbox");
 	gtk_entry_set_max_length (GTK_ENTRY (gui->input_box), 2048);
@@ -1976,17 +1981,6 @@ mg_create_entry (session *sess, GtkWidget *box)
 
 	if (prefs.style_inputbox)
 		mg_apply_entry_style (entry);
-
-/*	but = gtk_button_new ();
-	arrow = gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_NONE);
-	gtk_container_add (GTK_CONTAINER (but), arrow);
-	gtk_button_set_relief (GTK_BUTTON (but), GTK_RELIEF_NONE);
-	gtk_box_pack_end (GTK_BOX (hbox), but, 0, 0, 0);
-	g_signal_connect (G_OBJECT (but), "clicked",
-							G_CALLBACK (mg_upbutton_cb), 0);
-	add_tip (but, _("Channel Options"));
-	gtk_widget_set_size_request (but, 18, 8);
-	gtk_widget_show_all (but);*/
 }
 
 static void
@@ -2513,7 +2507,6 @@ mg_changui_new (session *sess, restore_gui *res, int tab)
 
 /*	while (g_main_pending ())
 		g_main_iteration (TRUE);*/
-	tab_group_resize (mg_gui->tabs_box);
 	/*g_idle_add ((GSourceFunc)tab_group_resize, mg_gui->tabs_box);*/
 }
 
