@@ -81,7 +81,7 @@ enum
 	M_MENUD,
 	M_MENUSTOCK,
 	M_MENUPIX,
-	M_MENUSUB,
+	M_MENUSUB
 };
 
 struct mymenu
@@ -855,7 +855,7 @@ menu_flushbuffer (GtkWidget * wid, gpointer none)
 }
 
 static void
-savebuffer_req_done (session *sess, void *arg2, char *file)
+savebuffer_req_done (session *sess, char *file)
 {
 	int fh;
 
@@ -874,7 +874,7 @@ static void
 menu_savebuffer (GtkWidget * wid, gpointer none)
 {
 	gtkutil_file_req (_("Select an output filename"), savebuffer_req_done,
-							current_sess, 0, TRUE);
+							current_sess, NULL, FRF_WRITE);
 }
 
 static void
