@@ -1,4 +1,4 @@
-GtkWidget *menu_create_main (void *accel_group, int bar, int away, GtkWidget **away_item, GtkWidget **user_menu);
+GtkWidget *menu_create_main (void *accel_group, int bar, int away, int toplevel, GtkWidget **away_item, GtkWidget **user_menu);
 void menu_newshell_set_palette (session *sess);
 void menu_urlmenu (GdkEventButton * event, char *url);
 void menu_chanmenu (session *sess, GdkEventButton * event, char *chan);
