@@ -60,6 +60,7 @@ GdkColor colors[] = {
 };
 #define MAX_COL 23
 
+
 void
 palette_alloc (GtkWidget * widget)
 {
@@ -72,7 +73,7 @@ palette_alloc (GtkWidget * widget)
 		done_alloc = TRUE;
 		cmap = gtk_widget_get_colormap (widget);
 		for (i = MAX_COL; i >= 0; i--)
-			gdk_colormap_alloc_color (cmap, &colors[i], TRUE, TRUE);
+			gdk_colormap_alloc_color (cmap, &colors[i], FALSE, TRUE);
 	}
 }
 
