@@ -74,6 +74,7 @@ plugingui_treeview_new (GtkWidget *box)
 	                             VERSION_COLUMN, _("Version"),
 	                             FILE_COLUMN, _("File"),
 	                             DESC_COLUMN, _("Description"), -1);
+	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (view), TRUE);
 	for (col_id=0; (col = gtk_tree_view_get_column (GTK_TREE_VIEW (view), col_id));
 	     col_id++)
 			gtk_tree_view_column_set_alignment (col, 0.5);
@@ -129,7 +130,7 @@ fe_pluginlist_update (void)
 }
 
 static void
-plugingui_load_cb (session *sess, void *data2, char *file)
+plugingui_load_cb (session *sess, char *file)
 {
 	if (file)
 	{
@@ -148,7 +149,7 @@ void
 plugingui_load (void)
 {
 	gtkutil_file_req (_("Select a Plugin or Script to load"), plugingui_load_cb,
-							current_sess, 0, FALSE);
+							current_sess, NULL, 0);
 }
 
 static void
