@@ -6,6 +6,13 @@
 #include <X11/Xft/Xft.h>
 #endif
 
+#ifdef USE_SHM
+#include <X11/Xlib.h>
+#include <sys/ipc.h>
+#include <sys/shm.h>
+#include <X11/extensions/XShm.h>
+#endif
+
 #define GTK_TYPE_XTEXT              (gtk_xtext_get_type ())
 #define GTK_XTEXT(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), GTK_TYPE_XTEXT, GtkXText))
 #define GTK_XTEXT_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST ((klass), GTK_TYPE_XTEXT, GtkXTextClass))
@@ -64,6 +71,10 @@ struct _GtkXText
 	xtext_buffer *orig_buffer;
 	xtext_buffer *selection_buffer;
 
+#ifdef USE_SHM
+	XShmSegmentInfo shminfo;
+#endif
+
 	GtkAdjustment *adj;
 	GdkPixmap *pixmap;				/* 0 = use palette[19] */
 	GdkDrawable *draw_buf;			/* points to ->window */
@@ -143,6 +154,15 @@ struct _GtkXText
 	int jump_out_offset;	/* point at which to stop rendering */
 	int jump_in_offset;	/* "" start rendering */
 
+	int ts_x;			/* ts origin for ->bgc GC */
+	int ts_y;
+
+	int clip_x;			/* clipping (x directions) */
+	int clip_x2;		/* from x to x2 */
+
+	int clip_y;			/* clipping (y directions) */
+	int clip_y2;		/* from y to y2 */
+
 	unsigned int auto_indent:1;
 	unsigned int moving_separator:1;
 	unsigned int word_or_line_select:1;
@@ -161,7 +181,6 @@ struct _GtkXText
 	unsigned int dont_render:1;
 	unsigned int dont_render2:1;
 	unsigned int cursor_hand:1;
-	unsigned int skip_fills:1;
 	unsigned int skip_border_fills:1;
 	unsigned int skip_stamp:1;
 	unsigned int render_hilights_only:1;
@@ -171,6 +190,7 @@ struct _GtkXText
 	unsigned int avoid_trans:1;
 	unsigned int overdraw:1;
 	unsigned int indent_changed:1;
+	unsigned int shm:1;
 };
 
 struct _GtkXTextClass
@@ -193,7 +213,7 @@ void gtk_xtext_save (GtkXText * xtext, int fh);
 void gtk_xtext_refresh (GtkXText * xtext, int do_trans);
 void *gtk_xtext_search (GtkXText * xtext, const unsigned char *text, void *start);
 
-gboolean gtk_xtext_is_empty (GtkXText * xtext);
+gboolean gtk_xtext_is_empty (xtext_buffer *buf);
 typedef void (*GtkXTextForeach) (GtkXText *xtext, unsigned char *text, void *data);
 void gtk_xtext_foreach (xtext_buffer *buf, GtkXTextForeach func, void *data);
 
